package Net::ACME::X::InvalidParameter;

use strict;
use warnings;

use parent qw( Net::ACME::X::HashBase );

#named args required:
#
#   value
#

1;
